**1.0.1 - 04/11/2024**

 - Extract python version test matrix from python_versions.json
 - Automatically update README when supported python versions change
 - Bugfix missing ConfigurationError attribute

**1.0.0 - 04/11/2024**

 - Initial release
